# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: mapped/cloud/types/calendar_period.proto, mapped/cloud/types/date.proto, mapped/cloud/types/dayofweek.proto, mapped/cloud/types/geojson.proto, mapped/cloud/types/interval.proto, mapped/cloud/types/metadata.proto, mapped/cloud/types/money.proto, mapped/cloud/types/month.proto, mapped/cloud/types/phone_number.proto, mapped/cloud/types/postal_address.proto, mapped/cloud/types/timeofday.proto, mapped/cloud/types/typed_value.proto
# plugin: python-betterproto
from dataclasses import dataclass
from datetime import datetime
from typing import (
    Dict,
    List,
)

import betterproto
import betterproto.lib.google.protobuf as betterproto_lib_google_protobuf


class CalendarPeriod(betterproto.Enum):
    """
    A `CalendarPeriod` represents the abstract concept of a time period that
    has a canonical start. Grammatically, "the start of the current
    `CalendarPeriod`." All calendar times begin at midnight UTC.
    """

    CALENDAR_PERIOD_UNSPECIFIED = 0
    """Undefined period, raises an error."""

    DAY = 1
    """A day."""

    WEEK = 2
    """
    A week. Weeks begin on Monday, following [ISO
    8601](https://en.wikipedia.org/wiki/ISO_week_date).
    """

    FORTNIGHT = 3
    """
    A fortnight. The first calendar fortnight of the year begins at the start
    of week 1 according to [ISO
    8601](https://en.wikipedia.org/wiki/ISO_week_date).
    """

    MONTH = 4
    """A month."""

    QUARTER = 5
    """
    A quarter. Quarters start on dates 1-Jan, 1-Apr, 1-Jul, and 1-Oct of each
    year.
    """

    HALF = 6
    """A half-year. Half-years start on dates 1-Jan and 1-Jul."""

    YEAR = 7
    """A year."""


class DayOfWeek(betterproto.Enum):
    """Represents a day of the week."""

    DAY_OF_WEEK_UNSPECIFIED = 0
    """The day of the week is unspecified."""

    MONDAY = 1
    """Monday"""

    TUESDAY = 2
    """Tuesday"""

    WEDNESDAY = 3
    """Wednesday"""

    THURSDAY = 4
    """Thursday"""

    FRIDAY = 5
    """Friday"""

    SATURDAY = 6
    """Saturday"""

    SUNDAY = 7
    """Sunday"""


class Month(betterproto.Enum):
    """Represents a month in the Gregorian calendar."""

    MONTH_UNSPECIFIED = 0
    """The unspecifed month."""

    JANUARY = 1
    """The month of January."""

    FEBRUARY = 2
    """The month of February."""

    MARCH = 3
    """The month of March."""

    APRIL = 4
    """The month of April."""

    MAY = 5
    """The month of May."""

    JUNE = 6
    """The month of June."""

    JULY = 7
    """The month of July."""

    AUGUST = 8
    """The month of August."""

    SEPTEMBER = 9
    """The month of September."""

    OCTOBER = 10
    """The month of October."""

    NOVEMBER = 11
    """The month of November."""

    DECEMBER = 12
    """The month of December."""


@dataclass(eq=False, repr=False)
class Date(betterproto.Message):
    """
    Represents a whole or partial calendar date, such as a birthday. The time
    of day and time zone are either specified elsewhere or are insignificant.
    The date is relative to the Gregorian Calendar. This can represent one of
    the following: * A full date, with non-zero year, month, and day values * A
    month and day value, with a zero year, such as an anniversary * A year on
    its own, with zero month and day values * A year and month value, with a
    zero day, such as a credit card expiration date Related types are
    [com.mapped.cloud.types.TimeOfDay][com.mapped.cloud.types.TimeOfDay] and
    `google.protobuf.Timestamp`. ISO-8601 compatible date only... Lacking a
    language specific "date onnly" format, it is recommended to hold this as a
    string in the ISO-8601 format ("yyyy-MM-dd")
    """

    year: int = betterproto.int32_field(1)
    """
    Year of the date. Must be from 1 to 9999, or 0 to specify a date without a
    year.
    """

    month: int = betterproto.int32_field(2)
    """
    Month of a year. Must be from 1 to 12, or 0 to specify a year without a
    month and day.
    """

    day: int = betterproto.int32_field(3)
    """
    Day of a month. Must be from 1 to 31 and valid for the year and month, or 0
    to specify a year by itself or a year and month where the day isn't
    significant.
    """


@dataclass(eq=False, repr=False)
class GeoPoint(betterproto.Message):
    """Represents a GeoPoint"""

    type: str = betterproto.string_field(1)
    coordinates: List[float] = betterproto.double_field(2)


@dataclass(eq=False, repr=False)
class Interval(betterproto.Message):
    """
    Represents a time interval, encoded as a Timestamp start (inclusive) and a
    Timestamp end (exclusive). The start must be less than or equal to the end.
    When the start equals the end, the interval is empty (matches no time).
    When both start and end are unspecified, the interval matches any time.
    """

    start_time: datetime = betterproto.message_field(1)
    """
    Optional. Inclusive start of the interval. If specified, a Timestamp
    matching this interval will have to be the same or after the start.
    """

    end_time: datetime = betterproto.message_field(2)
    """
    Optional. Exclusive end of the interval. If specified, a Timestamp matching
    this interval will have to be before the end.
    """


@dataclass(eq=False, repr=False)
class MetadataRecord(betterproto.Message):
    key: str = betterproto.string_field(1)
    value: str = betterproto.string_field(2)


@dataclass(eq=False, repr=False)
class MetadataValue(betterproto.Message):
    values: List["MetadataRecord"] = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class MetadataUpdate(betterproto.Message):
    granular: "MetadataUpdateGranular" = betterproto.message_field(1, group="update")
    replace: "MetadataValue" = betterproto.message_field(2, group="update")


@dataclass(eq=False, repr=False)
class MetadataUpdateGranular(betterproto.Message):
    add: List["MetadataRecord"] = betterproto.message_field(1)
    remove: List["MetadataRecord"] = betterproto.message_field(2)
    remove_all: List[str] = betterproto.string_field(3)


@dataclass(eq=False, repr=False)
class Money(betterproto.Message):
    """Represents an amount of money with its currency type."""

    currency_code: str = betterproto.string_field(1)
    """The three-letter currency code defined in ISO 4217."""

    units: int = betterproto.int64_field(2)
    """
    The whole units of the amount. For example if `currencyCode` is `"USD"`,
    then 1 unit is one US dollar.
    """

    nanos: int = betterproto.int32_field(3)
    """
    Number of nano (10^-9) units of the amount. The value must be between
    -999,999,999 and +999,999,999 inclusive. If `units` is positive, `nanos`
    must be positive or zero. If `units` is zero, `nanos` can be positive,
    zero, or negative. If `units` is negative, `nanos` must be negative or
    zero. For example $-1.75 is represented as `units`=-1 and
    `nanos`=-750,000,000.
    """


@dataclass(eq=False, repr=False)
class PhoneNumber(betterproto.Message):
    """
    An object representing a phone number, suitable as an API wire format. This
    representation:  - should not be used for locale-specific formatting of a
    phone number, such    as "+1 (650) 253-0000 ext. 123"  - is not designed
    for efficient storage  - may not be suitable for dialing - specialized
    libraries (see references)    should be used to parse the number for that
    purpose To do something meaningful with this number, such as format it for
    various use-cases, convert it to an `i18n.phonenumbers.PhoneNumber` object
    first. For instance, in Java this would be:
    com.mapped.cloud.types.PhoneNumber wireProto =
    com.mapped.cloud.types.PhoneNumber.newBuilder().build();
    com.google.i18n.phonenumbers.Phonenumber.PhoneNumber phoneNumber =
    PhoneNumberUtil.getInstance().parse(wireProto.getE164Number(), "ZZ");    if
    (!wireProto.getExtension().isEmpty()) {
    phoneNumber.setExtension(wireProto.getExtension());    }  Reference(s):   -
    https://github.com/google/libphonenumber
    """

    e164_number: str = betterproto.string_field(1, group="kind")
    """
    The phone number, represented as a leading plus sign ('+'), followed by a
    phone number that uses a relaxed ITU E.164 format consisting of the country
    calling code (1 to 3 digits) and the subscriber number, with no additional
    spaces or formatting, e.g.:  - correct: "+15552220123"  - incorrect: "+1
    (555) 222-01234 x123". The ITU E.164 format limits the latter to 12 digits,
    but in practice not all countries respect that, so we relax that
    restriction here. National-only numbers are not allowed. References:  -
    https://www.itu.int/rec/T-REC-E.164-201011-I  -
    https://en.wikipedia.org/wiki/E.164.  -
    https://en.wikipedia.org/wiki/List_of_country_calling_codes
    """

    short_code: "PhoneNumberShortCode" = betterproto.message_field(2, group="kind")
    """
    A short code. Reference(s):  - https://en.wikipedia.org/wiki/Short_code
    """

    extension: str = betterproto.string_field(3)
    """
    The phone number's extension. The extension is not standardized in ITU
    recommendations, except for being defined as a series of numbers with a
    maximum length of 40 digits. Other than digits, some other dialing
    characters such as ',' (indicating a wait) or '#' may be stored here. Note
    that no regions currently use extensions with short codes, so this field is
    normally only set in conjunction with an E.164 number. It is held
    separately from the E.164 number to allow for short code extensions in the
    future.
    """


@dataclass(eq=False, repr=False)
class PhoneNumberShortCode(betterproto.Message):
    """
    An object representing a short code, which is a phone number that is
    typically much shorter than regular phone numbers and can be used to
    address messages in MMS and SMS systems, as well as for abbreviated dialing
    (e.g. "Text 611 to see how many minutes you have remaining on your plan.").
    Short codes are restricted to a region and are not internationally
    dialable, which means the same short code can exist in different regions,
    with different usage and pricing, even if those regions share the same
    country calling code (e.g. US and CA).
    """

    region_code: str = betterproto.string_field(1)
    """
    Required. The BCP-47 region code of the location where calls to this short
    code can be made, such as "US" and "BB". Reference(s):  -
    http://www.unicode.org/reports/tr35/#unicode_region_subtag
    """

    number: str = betterproto.string_field(2)
    """
    Required. The short code digits, without a leading plus ('+') or country
    calling code, e.g. "611".
    """


@dataclass(eq=False, repr=False)
class PostalAddress(betterproto.Message):
    """
    Represents a postal address, e.g. for postal delivery or payments
    addresses. Given a postal address, a postal service can deliver items to a
    premise, P.O. Box or similar. It is not intended to model geographical
    locations (roads, towns, mountains). In typical usage an address would be
    created via user input or from importing existing data, depending on the
    type of process. Advice on address input / editing:  - Use an i18n-ready
    address widget such as    https://github.com/google/libaddressinput) -
    Users should not be presented with UI elements for input or editing of
    fields outside countries where that field is used. For more guidance on how
    to use this schema, please see:
    https://support.google.com/business/answer/6397478
    """

    revision: int = betterproto.int32_field(1)
    """
    The schema revision of the `PostalAddress`. This must be set to 0, which is
    the latest revision. All new revisions **must** be backward compatible with
    old revisions.
    """

    region_code: str = betterproto.string_field(2)
    """
    Required. CLDR region code of the country/region of the address. This is
    never inferred and it is up to the user to ensure the value is correct. See
    http://cldr.unicode.org/ and http://www.unicode.org/cldr/charts/30/suppleme
    ntal/territory_information.html for details. Example: "CH" for Switzerland.
    """

    language_code: str = betterproto.string_field(3)
    """
    Optional. BCP-47 language code of the contents of this address (if known).
    This is often the UI language of the input form or is expected to match one
    of the languages used in the address' country/region, or their
    transliterated equivalents. This can affect formatting in certain
    countries, but is not critical to the correctness of the data and will
    never affect any validation or other non-formatting related operations. If
    this value is not known, it should be omitted (rather than specifying a
    possibly incorrect default). Examples: "zh-Hant", "ja", "ja-Latn", "en".
    """

    postal_code: str = betterproto.string_field(4)
    """
    Optional. Postal code of the address. Not all countries use or require
    postal codes to be present, but where they are used, they may trigger
    additional validation with other parts of the address (e.g. state/zip
    validation in the U.S.A.).
    """

    sorting_code: str = betterproto.string_field(5)
    """
    Optional. Additional, country-specific, sorting code. This is not used in
    most regions. Where it is used, the value is either a string like "CEDEX",
    optionally followed by a number (e.g. "CEDEX 7"), or just a number alone,
    representing the "sector code" (Jamaica), "delivery area indicator"
    (Malawi) or "post office indicator" (e.g. Côte d'Ivoire).
    """

    administrative_area: str = betterproto.string_field(6)
    """
    Optional. Highest administrative subdivision which is used for postal
    addresses of a country or region. For example, this can be a state, a
    province, an oblast, or a prefecture. Specifically, for Spain this is the
    province and not the autonomous community (e.g. "Barcelona" and not
    "Catalonia"). Many countries don't use an administrative area in postal
    addresses. E.g. in Switzerland this should be left unpopulated.
    """

    locality: str = betterproto.string_field(7)
    """
    Optional. Generally refers to the city/town portion of the address.
    Examples: US city, IT comune, UK post town. In regions of the world where
    localities are not well defined or do not fit into this structure well,
    leave locality empty and use address_lines.
    """

    sublocality: str = betterproto.string_field(8)
    """
    Optional. Sublocality of the address. For example, this can be
    neighborhoods, boroughs, districts.
    """

    address_lines: List[str] = betterproto.string_field(9)
    """
    Unstructured address lines describing the lower levels of an address.
    Because values in address_lines do not have type information and may
    sometimes contain multiple values in a single field (e.g. "Austin, TX"), it
    is important that the line order is clear. The order of address lines
    should be "envelope order" for the country/region of the address. In places
    where this can vary (e.g. Japan), address_language is used to make it
    explicit (e.g. "ja" for large-to-small ordering and "ja-Latn" or "en" for
    small-to-large). This way, the most specific line of an address can be
    selected based on the language. The minimum permitted structural
    representation of an address consists of a region_code with all remaining
    information placed in the address_lines. It would be possible to format
    such an address very approximately without geocoding, but no semantic
    reasoning could be made about any of the address components until it was at
    least partially resolved. Creating an address only containing a region_code
    and address_lines, and then geocoding is the recommended way to handle
    completely unstructured addresses (as opposed to guessing which parts of
    the address should be localities or administrative areas).
    """

    recipients: List[str] = betterproto.string_field(10)
    """
    Optional. The recipient at the address. This field may, under certain
    circumstances, contain multiline information. For example, it might contain
    "care of" information.
    """

    organization: str = betterproto.string_field(11)
    """Optional. The name of the organization at the address."""


@dataclass(eq=False, repr=False)
class TimeOfDay(betterproto.Message):
    """
    Represents a time of day. The date and time zone are either not significant
    or are specified elsewhere. An API may choose to allow leap seconds.
    Related types are
    [com.mapped.cloud.types.Date][com.mapped.cloud.types.Date] and
    `google.protobuf.Timestamp`. ISO-8601 doesn't support time only, but we use
    the same fields here Lacking a language specific "time" format, it is
    recommended to hold this as a string in the ISO-8601 format
    ("HH:mm:ss.fffffffzzz")
    """

    hours: int = betterproto.int32_field(1)
    """
    Hours of day in 24 hour format. Should be from 0 to 23. An API may choose
    to allow the value "24:00:00" for scenarios like business closing time.
    """

    minutes: int = betterproto.int32_field(2)
    """Minutes of hour of day. Must be from 0 to 59."""

    seconds: int = betterproto.int32_field(3)
    """
    Seconds of minutes of the time. Must normally be from 0 to 59. An API may
    allow the value 60 if it allows leap-seconds.
    """

    nanos: int = betterproto.int32_field(4)
    """Fractions of seconds in nanoseconds. Must be from 0 to 999,999,999."""


@dataclass(eq=False, repr=False)
class ContextLinkedData(betterproto.Message):
    type: str = betterproto.string_field(1)


@dataclass(eq=False, repr=False)
class AnyLinkedData(betterproto.Message):
    """AnyLinkedData is used to represent JSONLD"""

    context: "ContextLinkedData" = betterproto.message_field(1)
    value: "betterproto_lib_google_protobuf.Struct" = betterproto.message_field(2)


@dataclass(eq=False, repr=False)
class AnyLinkedDataMap(betterproto.Message):
    map: Dict[str, "AnyLinkedData"] = betterproto.map_field(
        1, betterproto.TYPE_STRING, betterproto.TYPE_MESSAGE
    )


@dataclass(eq=False, repr=False)
class TypedValue(betterproto.Message):
    bool_value: bool = betterproto.bool_field(10, group="value")
    uint32_value: int = betterproto.uint32_field(11, group="value")
    uint64_value: int = betterproto.uint64_field(12, group="value")
    int32_value: int = betterproto.int32_field(13, group="value")
    int64_value: int = betterproto.int64_field(14, group="value")
    float32_value: float = betterproto.float_field(15, group="value")
    float64_value: float = betterproto.double_field(16, group="value")
    byte_array_value: bytes = betterproto.bytes_field(17, group="value")
    string_value: str = betterproto.string_field(18, group="value")
    uuid_value: bytes = betterproto.bytes_field(19, group="value")
    bool_array_value: "BoolArray" = betterproto.message_field(20, group="value")
    enum_value: int = betterproto.uint32_field(21, group="value")
    date_value: "Date" = betterproto.message_field(22, group="value")
    time_value: "TimeOfDay" = betterproto.message_field(23, group="value")
    timestamp_value: datetime = betterproto.message_field(24, group="value")
    geojson_value: "betterproto_lib_google_protobuf.Struct" = betterproto.message_field(
        25, group="value"
    )
    geopoint_value: "GeoPoint" = betterproto.message_field(28, group="value")
    json: "AnyLinkedData" = betterproto.message_field(29, group="value")
    map_value: "GenericTypedMap" = betterproto.message_field(30, group="value")
    calendar_period_value: "CalendarPeriod" = betterproto.enum_field(100, group="value")
    """Proposed types"""

    day_of_week_value: "DayOfWeek" = betterproto.enum_field(101, group="value")
    interval_value: "Interval" = betterproto.message_field(102, group="value")
    money_value: "Money" = betterproto.message_field(103, group="value")
    month_value: "Month" = betterproto.enum_field(104, group="value")
    phone_number_value: "PhoneNumber" = betterproto.message_field(105, group="value")
    postal_address_value: "PostalAddress" = betterproto.message_field(
        106, group="value"
    )


@dataclass(eq=False, repr=False)
class TypedValueMap(betterproto.Message):
    map: Dict[str, "TypedValue"] = betterproto.map_field(
        1, betterproto.TYPE_STRING, betterproto.TYPE_MESSAGE
    )


@dataclass(eq=False, repr=False)
class GenericTypedMap(betterproto.Message):
    entries: List["GenericTypedMapEntry"] = betterproto.message_field(1)


@dataclass(eq=False, repr=False)
class GenericTypedMapEntry(betterproto.Message):
    key: "TypedValue" = betterproto.message_field(1)
    value: "TypedValue" = betterproto.message_field(2)


@dataclass(eq=False, repr=False)
class BoolArray(betterproto.Message):
    values: List[bool] = betterproto.bool_field(1)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mapped/cloud/types/interval.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!mapped/cloud/types/interval.proto\x12\x12mapped.cloud.types\x1a\x1fgoogle/protobuf/timestamp.proto\"|\n\x08Interval\x12\x39\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x35\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x65ndTimeBV\n\x16\x63om.mapped.cloud.typesP\x01Z\"go.mapped.dev/pb/cloud/types;types\xf8\x01\x01\xaa\x02\x12Mapped.Cloud.Typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mapped.cloud.types.interval_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.mapped.cloud.typesP\001Z\"go.mapped.dev/pb/cloud/types;types\370\001\001\252\002\022Mapped.Cloud.Types'
  _INTERVAL._serialized_start=90
  _INTERVAL._serialized_end=214
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mapped/gateway/redispoint.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from mapped.cloud.types import typed_value_pb2 as mapped_dot_cloud_dot_types_dot_typed__value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fmapped/gateway/redispoint.proto\x12\x0emapped.gateway\x1a\x1fgoogle/protobuf/timestamp.proto\x1a$mapped/cloud/types/typed_value.proto\"\xa1\x02\n\nRedisPoint\x12\x43\n\rpresent_value\x18\x01 \x01(\x0b\x32\x1e.mapped.cloud.types.TypedValueR\x0cpresentValue\x12;\n\x0blast_update\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nlastUpdate\x12J\n\x13network_error_start\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x11networkErrorStart\x12\x45\n\x1f\x63onsecutive_network_error_count\x18\x04 \x01(\rR\x1c\x63onsecutiveNetworkErrorCountBI\n\x12\x63om.mapped.gatewayP\x01Z go.mapped.dev/pb/gateway;gateway\xaa\x02\x0eMapped.Gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mapped.gateway.redispoint_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022com.mapped.gatewayP\001Z go.mapped.dev/pb/gateway;gateway\252\002\016Mapped.Gateway'
  _REDISPOINT._serialized_start=123
  _REDISPOINT._serialized_end=412
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: mapped/gateway/edgecontrol.proto, mapped/gateway/redispoint.proto
# plugin: python-betterproto
from dataclasses import dataclass
from datetime import datetime
from typing import (
    TYPE_CHECKING,
    AsyncIterator,
    Dict,
    List,
    Optional,
)

import betterproto
import grpclib
from betterproto.grpc.grpclib_server import ServiceBase

from ..cloud import types as _cloud_types__


if TYPE_CHECKING:
    import grpclib.server
    from betterproto.grpc.grpclib_client import MetadataLike
    from grpclib.metadata import Deadline


class Result(betterproto.Enum):
    RESULT_UNSPECIFIED = 0
    SUCCESS = 1
    """Success codes (1-99)"""

    ERROR_UNKNOWN = 100
    """Error codes (100+)"""

    ERROR_UNKNOWN_MAPPING_KEY = 101
    ERROR_TIMEOUT = 103
    ERROR_HOST_UNREACHABLE = 104
    ERROR_VALUE_TYPE_CHANGE = 120
    ERROR_VALUE_ARRAY_INDEX_INVALID = 121
    ERROR_VALUE_TYPE_INVALID = 122
    ERROR_VALUE_TYPE_UNSUPPORTED = 123
    ERROR_VALUE_NOT_ARRAY = 124
    ERROR_VALUE_OUT_OF_RANGE = 125
    ERROR_VALUE_WRITE_ACCESS_DENIED = 126
    ERROR_DEVICE_OTHER = 150
    ERROR_DEVICE_NO_WRITE_SUPPORT = 151
    ERROR_DEVICE_ACCESS_DENIED = 152


@dataclass(eq=False, repr=False)
class WritePropsRequest(betterproto.Message):
    values: List["MappingKeyAndValue"] = betterproto.message_field(1)
    """The property value(s) to write"""

    timeout_per_device_in_ms: int = betterproto.uint32_field(2)
    """
    The timeout for each request to each subtended device in milliseconds NOTE:
    UGAgent makes every attempt to parallelize these, but some devices don't
    support       writing multiple properties at once, which means write
    requests must be serialized
    """

    simulate: bool = betterproto.bool_field(100)
    """
    Simulate the command by only validating the input and logging do not send
    actual commands over the wire
    """


@dataclass(eq=False, repr=False)
class WritePropsResponse(betterproto.Message):
    request_id: str = betterproto.string_field(1)
    """
    The unique ID of this request to be provided to Mapped Support for
    troubleshooting in the case of unexpected errors
    """

    results: List["MappingKeyAndResult"] = betterproto.message_field(2)
    """The result of each property write"""


@dataclass(eq=False, repr=False)
class MappingKeyAndValue(betterproto.Message):
    mapping_key: str = betterproto.string_field(1)
    """
    The mappingKey where the value originated from or is to be written to
    """

    value: "_cloud_types__.TypedValue" = betterproto.message_field(2)
    """
    The value read or to be written  NOTE: The value *type* must NOT change
    type between a read and a write
    """


@dataclass(eq=False, repr=False)
class MappingKeyAndResult(betterproto.Message):
    mapping_key: str = betterproto.string_field(1)
    """The mappingKey where the this result originated from"""

    result: "Result" = betterproto.enum_field(2)
    """The result code"""

    error_description: str = betterproto.string_field(3)
    """Error description (if available)"""

    protocol_error_class: int = betterproto.int64_field(4)
    """
    Protocol-specific error class, for protocols that split class/code - like
    BACnet
    """

    protocol_error_code: int = betterproto.int64_field(5)
    """Protocol-specific error code"""


@dataclass(eq=False, repr=False)
class RedisPoint(betterproto.Message):
    """RedisPoint is used for edge present value streams in Redis"""

    present_value: "_cloud_types__.TypedValue" = betterproto.message_field(1)
    """The present value of this point"""

    last_update: datetime = betterproto.message_field(2)
    """The timestamp of when the point was last updated in the Mapped UG"""

    network_error_start: datetime = betterproto.message_field(3)
    """
    The timestamp of when network errors started for this point (or really, the
    deivce that owns this point) A zero value (seconds==0; nanos==0) means
    there are no network issues
    """

    consecutive_network_error_count: int = betterproto.uint32_field(4)
    """
    A count of how many consecutive network errors have been observed since
    `network_error_start` A zero value (==0) here means there are there were no
    network errors in the last update to this point
    """


class EdgeControlServiceStub(betterproto.ServiceStub):
    async def write_props(
        self,
        write_props_request: "WritePropsRequest",
        *,
        timeout: Optional[float] = None,
        deadline: Optional["Deadline"] = None,
        metadata: Optional["MetadataLike"] = None
    ) -> AsyncIterator["WritePropsResponse"]:
        async for response in self._unary_stream(
            "/mapped.gateway.EdgeControlService/WriteProps",
            write_props_request,
            WritePropsResponse,
            timeout=timeout,
            deadline=deadline,
            metadata=metadata,
        ):
            yield response


class EdgeControlServiceBase(ServiceBase):
    async def write_props(
        self, write_props_request: "WritePropsRequest"
    ) -> AsyncIterator["WritePropsResponse"]:
        raise grpclib.GRPCError(grpclib.const.Status.UNIMPLEMENTED)

    async def __rpc_write_props(
        self, stream: "grpclib.server.Stream[WritePropsRequest, WritePropsResponse]"
    ) -> None:
        request = await stream.recv_message()
        await self._call_rpc_handler_server_stream(
            self.write_props,
            stream,
            request,
        )

    def __mapping__(self) -> Dict[str, grpclib.const.Handler]:
        return {
            "/mapped.gateway.EdgeControlService/WriteProps": grpclib.const.Handler(
                self.__rpc_write_props,
                grpclib.const.Cardinality.UNARY_STREAM,
                WritePropsRequest,
                WritePropsResponse,
            ),
        }



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mapped/cloud/types/typed_value.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from mapped.cloud.types import calendar_period_pb2 as mapped_dot_cloud_dot_types_dot_calendar__period__pb2
from mapped.cloud.types import date_pb2 as mapped_dot_cloud_dot_types_dot_date__pb2
from mapped.cloud.types import dayofweek_pb2 as mapped_dot_cloud_dot_types_dot_dayofweek__pb2
from mapped.cloud.types import interval_pb2 as mapped_dot_cloud_dot_types_dot_interval__pb2
from mapped.cloud.types import money_pb2 as mapped_dot_cloud_dot_types_dot_money__pb2
from mapped.cloud.types import month_pb2 as mapped_dot_cloud_dot_types_dot_month__pb2
from mapped.cloud.types import phone_number_pb2 as mapped_dot_cloud_dot_types_dot_phone__number__pb2
from mapped.cloud.types import postal_address_pb2 as mapped_dot_cloud_dot_types_dot_postal__address__pb2
from mapped.cloud.types import timeofday_pb2 as mapped_dot_cloud_dot_types_dot_timeofday__pb2
from mapped.cloud.types import geojson_pb2 as mapped_dot_cloud_dot_types_dot_geojson__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$mapped/cloud/types/typed_value.proto\x12\x12mapped.cloud.types\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a(mapped/cloud/types/calendar_period.proto\x1a\x1dmapped/cloud/types/date.proto\x1a\"mapped/cloud/types/dayofweek.proto\x1a!mapped/cloud/types/interval.proto\x1a\x1emapped/cloud/types/money.proto\x1a\x1emapped/cloud/types/month.proto\x1a%mapped/cloud/types/phone_number.proto\x1a\'mapped/cloud/types/postal_address.proto\x1a\"mapped/cloud/types/timeofday.proto\x1a mapped/cloud/types/geojson.proto\"\'\n\x11\x43ontextLinkedData\x12\x12\n\x04type\x18\x01 \x01(\tR\x04type\"\x80\x01\n\rAnyLinkedData\x12@\n\x07\x63ontext\x18\x01 \x01(\x0b\x32%.mapped.cloud.types.ContextLinkedDataR\x08@context\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructR\x05value\"\xae\x01\n\x10\x41nyLinkedDataMap\x12?\n\x03map\x18\x01 \x03(\x0b\x32-.mapped.cloud.types.AnyLinkedDataMap.MapEntryR\x03map\x1aY\n\x08MapEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x37\n\x05value\x18\x02 \x01(\x0b\x32!.mapped.cloud.types.AnyLinkedDataR\x05value:\x02\x38\x01\"\xc9\x0b\n\nTypedValue\x12\x1f\n\nbool_value\x18\n \x01(\x08H\x00R\tboolValue\x12#\n\x0cuint32_value\x18\x0b \x01(\rH\x00R\x0buint32Value\x12#\n\x0cuint64_value\x18\x0c \x01(\x04H\x00R\x0buint64Value\x12!\n\x0bint32_value\x18\r \x01(\x05H\x00R\nint32Value\x12!\n\x0bint64_value\x18\x0e \x01(\x03H\x00R\nint64Value\x12%\n\rfloat32_value\x18\x0f \x01(\x02H\x00R\x0c\x66loat32Value\x12%\n\rfloat64_value\x18\x10 \x01(\x01H\x00R\x0c\x66loat64Value\x12*\n\x10\x62yte_array_value\x18\x11 \x01(\x0cH\x00R\x0e\x62yteArrayValue\x12#\n\x0cstring_value\x18\x12 \x01(\tH\x00R\x0bstringValue\x12\x1f\n\nuuid_value\x18\x13 \x01(\x0cH\x00R\tuuidValue\x12I\n\x10\x62ool_array_value\x18\x14 \x01(\x0b\x32\x1d.mapped.cloud.types.BoolArrayH\x00R\x0e\x62oolArrayValue\x12\x1f\n\nenum_value\x18\x15 \x01(\rH\x00R\tenumValue\x12\x39\n\ndate_value\x18\x16 \x01(\x0b\x32\x18.mapped.cloud.types.DateH\x00R\tdateValue\x12>\n\ntime_value\x18\x17 \x01(\x0b\x32\x1d.mapped.cloud.types.TimeOfDayH\x00R\ttimeValue\x12\x45\n\x0ftimestamp_value\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x0etimestampValue\x12>\n\rgeojson_value\x18\x19 \x01(\x0b\x32\x17.google.protobuf.StructH\x00R\x0cgeojsonValue\x12\x45\n\x0egeopoint_value\x18\x1c \x01(\x0b\x32\x1c.mapped.cloud.types.GeoPointH\x00R\rgeopointValue\x12\x37\n\x04json\x18\x1d \x01(\x0b\x32!.mapped.cloud.types.AnyLinkedDataH\x00R\x04json\x12\x42\n\tmap_value\x18\x1e \x01(\x0b\x32#.mapped.cloud.types.GenericTypedMapH\x00R\x08mapValue\x12X\n\x15\x63\x61lendar_period_value\x18\x64 \x01(\x0e\x32\".mapped.cloud.types.CalendarPeriodH\x00R\x13\x63\x61lendarPeriodValue\x12J\n\x11\x64\x61y_of_week_value\x18\x65 \x01(\x0e\x32\x1d.mapped.cloud.types.DayOfWeekH\x00R\x0e\x64\x61yOfWeekValue\x12\x45\n\x0einterval_value\x18\x66 \x01(\x0b\x32\x1c.mapped.cloud.types.IntervalH\x00R\rintervalValue\x12<\n\x0bmoney_value\x18g \x01(\x0b\x32\x19.mapped.cloud.types.MoneyH\x00R\nmoneyValue\x12<\n\x0bmonth_value\x18h \x01(\x0e\x32\x19.mapped.cloud.types.MonthH\x00R\nmonthValue\x12O\n\x12phone_number_value\x18i \x01(\x0b\x32\x1f.mapped.cloud.types.PhoneNumberH\x00R\x10phoneNumberValue\x12U\n\x14postal_address_value\x18j \x01(\x0b\x32!.mapped.cloud.types.PostalAddressH\x00R\x12postalAddressValueB\x07\n\x05value\"\xa5\x01\n\rTypedValueMap\x12<\n\x03map\x18\x01 \x03(\x0b\x32*.mapped.cloud.types.TypedValueMap.MapEntryR\x03map\x1aV\n\x08MapEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32\x1e.mapped.cloud.types.TypedValueR\x05value:\x02\x38\x01\"\xc7\x01\n\x0fGenericTypedMap\x12\x43\n\x07\x65ntries\x18\x01 \x03(\x0b\x32).mapped.cloud.types.GenericTypedMap.EntryR\x07\x65ntries\x1ao\n\x05\x45ntry\x12\x30\n\x03key\x18\x01 \x01(\x0b\x32\x1e.mapped.cloud.types.TypedValueR\x03key\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32\x1e.mapped.cloud.types.TypedValueR\x05value\"#\n\tBoolArray\x12\x16\n\x06values\x18\x01 \x03(\x08R\x06valuesBS\n\x16\x63om.mapped.cloud.typesP\x01Z\"go.mapped.dev/pb/cloud/types;types\xaa\x02\x12Mapped.Cloud.Typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mapped.cloud.types.typed_value_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.mapped.cloud.typesP\001Z\"go.mapped.dev/pb/cloud/types;types\252\002\022Mapped.Cloud.Types'
  _ANYLINKEDDATAMAP_MAPENTRY._options = None
  _ANYLINKEDDATAMAP_MAPENTRY._serialized_options = b'8\001'
  _TYPEDVALUEMAP_MAPENTRY._options = None
  _TYPEDVALUEMAP_MAPENTRY._serialized_options = b'8\001'
  _CONTEXTLINKEDDATA._serialized_start=481
  _CONTEXTLINKEDDATA._serialized_end=520
  _ANYLINKEDDATA._serialized_start=523
  _ANYLINKEDDATA._serialized_end=651
  _ANYLINKEDDATAMAP._serialized_start=654
  _ANYLINKEDDATAMAP._serialized_end=828
  _ANYLINKEDDATAMAP_MAPENTRY._serialized_start=739
  _ANYLINKEDDATAMAP_MAPENTRY._serialized_end=828
  _TYPEDVALUE._serialized_start=831
  _TYPEDVALUE._serialized_end=2312
  _TYPEDVALUEMAP._serialized_start=2315
  _TYPEDVALUEMAP._serialized_end=2480
  _TYPEDVALUEMAP_MAPENTRY._serialized_start=2394
  _TYPEDVALUEMAP_MAPENTRY._serialized_end=2480
  _GENERICTYPEDMAP._serialized_start=2483
  _GENERICTYPEDMAP._serialized_end=2682
  _GENERICTYPEDMAP_ENTRY._serialized_start=2571
  _GENERICTYPEDMAP_ENTRY._serialized_end=2682
  _BOOLARRAY._serialized_start=2684
  _BOOLARRAY._serialized_end=2719
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mapped/cloud/types/month.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1emapped/cloud/types/month.proto\x12\x12mapped.cloud.types*\xb0\x01\n\x05Month\x12\x15\n\x11MONTH_UNSPECIFIED\x10\x00\x12\x0b\n\x07JANUARY\x10\x01\x12\x0c\n\x08\x46\x45\x42RUARY\x10\x02\x12\t\n\x05MARCH\x10\x03\x12\t\n\x05\x41PRIL\x10\x04\x12\x07\n\x03MAY\x10\x05\x12\x08\n\x04JUNE\x10\x06\x12\x08\n\x04JULY\x10\x07\x12\n\n\x06\x41UGUST\x10\x08\x12\r\n\tSEPTEMBER\x10\t\x12\x0b\n\x07OCTOBER\x10\n\x12\x0c\n\x08NOVEMBER\x10\x0b\x12\x0c\n\x08\x44\x45\x43\x45MBER\x10\x0c\x42V\n\x16\x63om.mapped.cloud.typesP\x01Z\"go.mapped.dev/pb/cloud/types;types\xf8\x01\x01\xaa\x02\x12Mapped.Cloud.Typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mapped.cloud.types.month_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.mapped.cloud.typesP\001Z\"go.mapped.dev/pb/cloud/types;types\370\001\001\252\002\022Mapped.Cloud.Types'
  _MONTH._serialized_start=55
  _MONTH._serialized_end=231
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mapped/cloud/types/timeofday.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"mapped/cloud/types/timeofday.proto\x12\x12mapped.cloud.types\"k\n\tTimeOfDay\x12\x14\n\x05hours\x18\x01 \x01(\x05R\x05hours\x12\x18\n\x07minutes\x18\x02 \x01(\x05R\x07minutes\x12\x18\n\x07seconds\x18\x03 \x01(\x05R\x07seconds\x12\x14\n\x05nanos\x18\x04 \x01(\x05R\x05nanosBf\n\x16\x63om.mapped.cloud.typesB\x0eTimeOfDayProtoP\x01Z\"go.mapped.dev/pb/cloud/types;types\xf8\x01\x01\xaa\x02\x12Mapped.Cloud.Typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mapped.cloud.types.timeofday_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.mapped.cloud.typesB\016TimeOfDayProtoP\001Z\"go.mapped.dev/pb/cloud/types;types\370\001\001\252\002\022Mapped.Cloud.Types'
  _TIMEOFDAY._serialized_start=58
  _TIMEOFDAY._serialized_end=165
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mapped/cloud/types/postal_address.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'mapped/cloud/types/postal_address.proto\x12\x12mapped.cloud.types\"\x8d\x03\n\rPostalAddress\x12\x1a\n\x08revision\x18\x01 \x01(\x05R\x08revision\x12\x1f\n\x0bregion_code\x18\x02 \x01(\tR\nregionCode\x12#\n\rlanguage_code\x18\x03 \x01(\tR\x0clanguageCode\x12\x1f\n\x0bpostal_code\x18\x04 \x01(\tR\npostalCode\x12!\n\x0csorting_code\x18\x05 \x01(\tR\x0bsortingCode\x12/\n\x13\x61\x64ministrative_area\x18\x06 \x01(\tR\x12\x61\x64ministrativeArea\x12\x1a\n\x08locality\x18\x07 \x01(\tR\x08locality\x12 \n\x0bsublocality\x18\x08 \x01(\tR\x0bsublocality\x12#\n\raddress_lines\x18\t \x03(\tR\x0c\x61\x64\x64ressLines\x12\x1e\n\nrecipients\x18\n \x03(\tR\nrecipients\x12\"\n\x0corganization\x18\x0b \x01(\tR\x0corganizationBV\n\x16\x63om.mapped.cloud.typesP\x01Z\"go.mapped.dev/pb/cloud/types;types\xf8\x01\x01\xaa\x02\x12Mapped.Cloud.Typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mapped.cloud.types.postal_address_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.mapped.cloud.typesP\001Z\"go.mapped.dev/pb/cloud/types;types\370\001\001\252\002\022Mapped.Cloud.Types'
  _POSTALADDRESS._serialized_start=64
  _POSTALADDRESS._serialized_end=461
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mapped/cloud/types/phone_number.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%mapped/cloud/types/phone_number.proto\x12\x12mapped.cloud.types\"\xe8\x01\n\x0bPhoneNumber\x12!\n\x0b\x65\x31\x36\x34_number\x18\x01 \x01(\tH\x00R\ne164Number\x12J\n\nshort_code\x18\x02 \x01(\x0b\x32).mapped.cloud.types.PhoneNumber.ShortCodeH\x00R\tshortCode\x12\x1c\n\textension\x18\x03 \x01(\tR\textension\x1a\x44\n\tShortCode\x12\x1f\n\x0bregion_code\x18\x01 \x01(\tR\nregionCode\x12\x16\n\x06number\x18\x02 \x01(\tR\x06numberB\x06\n\x04kindBV\n\x16\x63om.mapped.cloud.typesP\x01Z\"go.mapped.dev/pb/cloud/types;types\xf8\x01\x01\xaa\x02\x12Mapped.Cloud.Typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mapped.cloud.types.phone_number_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.mapped.cloud.typesP\001Z\"go.mapped.dev/pb/cloud/types;types\370\001\001\252\002\022Mapped.Cloud.Types'
  _PHONENUMBER._serialized_start=62
  _PHONENUMBER._serialized_end=294
  _PHONENUMBER_SHORTCODE._serialized_start=218
  _PHONENUMBER_SHORTCODE._serialized_end=286
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mapped/cloud/types/dayofweek.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"mapped/cloud/types/dayofweek.proto\x12\x12mapped.cloud.types*\x84\x01\n\tDayOfWeek\x12\x1b\n\x17\x44\x41Y_OF_WEEK_UNSPECIFIED\x10\x00\x12\n\n\x06MONDAY\x10\x01\x12\x0b\n\x07TUESDAY\x10\x02\x12\r\n\tWEDNESDAY\x10\x03\x12\x0c\n\x08THURSDAY\x10\x04\x12\n\n\x06\x46RIDAY\x10\x05\x12\x0c\n\x08SATURDAY\x10\x06\x12\n\n\x06SUNDAY\x10\x07\x42\x66\n\x16\x63om.mapped.cloud.typesB\x0e\x44\x61yOfWeekProtoP\x01Z\"go.mapped.dev/pb/cloud/types;types\xf8\x01\x01\xaa\x02\x12Mapped.Cloud.Typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mapped.cloud.types.dayofweek_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.mapped.cloud.typesB\016DayOfWeekProtoP\001Z\"go.mapped.dev/pb/cloud/types;types\370\001\001\252\002\022Mapped.Cloud.Types'
  _DAYOFWEEK._serialized_start=59
  _DAYOFWEEK._serialized_end=191
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mapped/cloud/types/date.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dmapped/cloud/types/date.proto\x12\x12mapped.cloud.types\"B\n\x04\x44\x61te\x12\x12\n\x04year\x18\x01 \x01(\x05R\x04year\x12\x14\n\x05month\x18\x02 \x01(\x05R\x05month\x12\x10\n\x03\x64\x61y\x18\x03 \x01(\x05R\x03\x64\x61yBV\n\x16\x63om.mapped.cloud.typesP\x01Z\"go.mapped.dev/pb/cloud/types;types\xf8\x01\x01\xaa\x02\x12Mapped.Cloud.Typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mapped.cloud.types.date_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.mapped.cloud.typesP\001Z\"go.mapped.dev/pb/cloud/types;types\370\001\001\252\002\022Mapped.Cloud.Types'
  _DATE._serialized_start=53
  _DATE._serialized_end=119
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mapped/cloud/types/calendar_period.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(mapped/cloud/types/calendar_period.proto\x12\x12mapped.cloud.types*\x7f\n\x0e\x43\x61lendarPeriod\x12\x1f\n\x1b\x43\x41LENDAR_PERIOD_UNSPECIFIED\x10\x00\x12\x07\n\x03\x44\x41Y\x10\x01\x12\x08\n\x04WEEK\x10\x02\x12\r\n\tFORTNIGHT\x10\x03\x12\t\n\x05MONTH\x10\x04\x12\x0b\n\x07QUARTER\x10\x05\x12\x08\n\x04HALF\x10\x06\x12\x08\n\x04YEAR\x10\x07\x42V\n\x16\x63om.mapped.cloud.typesP\x01Z\"go.mapped.dev/pb/cloud/types;types\xf8\x01\x01\xaa\x02\x12Mapped.Cloud.Typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mapped.cloud.types.calendar_period_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.mapped.cloud.typesP\001Z\"go.mapped.dev/pb/cloud/types;types\370\001\001\252\002\022Mapped.Cloud.Types'
  _CALENDARPERIOD._serialized_start=64
  _CALENDARPERIOD._serialized_end=191
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mapped/gateway/edgecontrol.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from mapped.cloud.types import typed_value_pb2 as mapped_dot_cloud_dot_types_dot_typed__value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n mapped/gateway/edgecontrol.proto\x12\x0emapped.gateway\x1a$mapped/cloud/types/typed_value.proto\"\xa3\x01\n\x11WritePropsRequest\x12:\n\x06values\x18\x01 \x03(\x0b\x32\".mapped.gateway.MappingKeyAndValueR\x06values\x12\x36\n\x18timeout_per_device_in_ms\x18\x02 \x01(\rR\x14timeoutPerDeviceInMs\x12\x1a\n\x08simulate\x18\x64 \x01(\x08R\x08simulate\"r\n\x12WritePropsResponse\x12\x1d\n\nrequest_id\x18\x01 \x01(\tR\trequestId\x12=\n\x07results\x18\x02 \x03(\x0b\x32#.mapped.gateway.MappingKeyAndResultR\x07results\"k\n\x12MappingKeyAndValue\x12\x1f\n\x0bmapping_key\x18\x01 \x01(\tR\nmappingKey\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32\x1e.mapped.cloud.types.TypedValueR\x05value\"\xf5\x01\n\x13MappingKeyAndResult\x12\x1f\n\x0bmapping_key\x18\x01 \x01(\tR\nmappingKey\x12.\n\x06result\x18\x02 \x01(\x0e\x32\x16.mapped.gateway.ResultR\x06result\x12+\n\x11\x65rror_description\x18\x03 \x01(\tR\x10\x65rrorDescription\x12\x30\n\x14protocol_error_class\x18\x04 \x01(\x03R\x12protocolErrorClass\x12.\n\x13protocol_error_code\x18\x05 \x01(\x03R\x11protocolErrorCode*\xcc\x03\n\x06Result\x12\x16\n\x12RESULT_UNSPECIFIED\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x11\n\rERROR_UNKNOWN\x10\x64\x12\x1d\n\x19\x45RROR_UNKNOWN_MAPPING_KEY\x10\x65\x12\x11\n\rERROR_TIMEOUT\x10g\x12\x1a\n\x16\x45RROR_HOST_UNREACHABLE\x10h\x12\x1b\n\x17\x45RROR_VALUE_TYPE_CHANGE\x10x\x12#\n\x1f\x45RROR_VALUE_ARRAY_INDEX_INVALID\x10y\x12\x1c\n\x18\x45RROR_VALUE_TYPE_INVALID\x10z\x12 \n\x1c\x45RROR_VALUE_TYPE_UNSUPPORTED\x10{\x12\x19\n\x15\x45RROR_VALUE_NOT_ARRAY\x10|\x12\x1c\n\x18\x45RROR_VALUE_OUT_OF_RANGE\x10}\x12#\n\x1f\x45RROR_VALUE_WRITE_ACCESS_DENIED\x10~\x12\x17\n\x12\x45RROR_DEVICE_OTHER\x10\x96\x01\x12\"\n\x1d\x45RROR_DEVICE_NO_WRITE_SUPPORT\x10\x97\x01\x12\x1f\n\x1a\x45RROR_DEVICE_ACCESS_DENIED\x10\x98\x01\x32k\n\x12\x45\x64geControlService\x12U\n\nWriteProps\x12!.mapped.gateway.WritePropsRequest\x1a\".mapped.gateway.WritePropsResponse0\x01\x42I\n\x12\x63om.mapped.gatewayP\x01Z go.mapped.dev/pb/gateway;gateway\xaa\x02\x0eMapped.Gatewayb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mapped.gateway.edgecontrol_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022com.mapped.gatewayP\001Z go.mapped.dev/pb/gateway;gateway\252\002\016Mapped.Gateway'
  _RESULT._serialized_start=730
  _RESULT._serialized_end=1190
  _WRITEPROPSREQUEST._serialized_start=91
  _WRITEPROPSREQUEST._serialized_end=254
  _WRITEPROPSRESPONSE._serialized_start=256
  _WRITEPROPSRESPONSE._serialized_end=370
  _MAPPINGKEYANDVALUE._serialized_start=372
  _MAPPINGKEYANDVALUE._serialized_end=479
  _MAPPINGKEYANDRESULT._serialized_start=482
  _MAPPINGKEYANDRESULT._serialized_end=727
  _EDGECONTROLSERVICE._serialized_start=1192
  _EDGECONTROLSERVICE._serialized_end=1299
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mapped/cloud/types/metadata.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!mapped/cloud/types/metadata.proto\x12\x12mapped.cloud.types\"8\n\x0eMetadataRecord\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value\"K\n\rMetadataValue\x12:\n\x06values\x18\x01 \x03(\x0b\x32\".mapped.cloud.types.MetadataRecordR\x06values\"\xc2\x02\n\x0eMetadataUpdate\x12I\n\x08granular\x18\x01 \x01(\x0b\x32+.mapped.cloud.types.MetadataUpdate.GranularH\x00R\x08granular\x12=\n\x07replace\x18\x02 \x01(\x0b\x32!.mapped.cloud.types.MetadataValueH\x00R\x07replace\x1a\x9b\x01\n\x08Granular\x12\x34\n\x03\x61\x64\x64\x18\x01 \x03(\x0b\x32\".mapped.cloud.types.MetadataRecordR\x03\x61\x64\x64\x12:\n\x06remove\x18\x02 \x03(\x0b\x32\".mapped.cloud.types.MetadataRecordR\x06remove\x12\x1d\n\nremove_all\x18\x03 \x03(\tR\tremoveAllB\x08\n\x06updateBV\n\x16\x63om.mapped.cloud.typesP\x01Z\"go.mapped.dev/pb/cloud/types;types\xf8\x01\x01\xaa\x02\x12Mapped.Cloud.Typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mapped.cloud.types.metadata_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.mapped.cloud.typesP\001Z\"go.mapped.dev/pb/cloud/types;types\370\001\001\252\002\022Mapped.Cloud.Types'
  _METADATARECORD._serialized_start=57
  _METADATARECORD._serialized_end=113
  _METADATAVALUE._serialized_start=115
  _METADATAVALUE._serialized_end=190
  _METADATAUPDATE._serialized_start=193
  _METADATAUPDATE._serialized_end=515
  _METADATAUPDATE_GRANULAR._serialized_start=350
  _METADATAUPDATE_GRANULAR._serialized_end=505
# @@protoc_insertion_point(module_scope)
